pub struct F32Vector<'a> { /* private fields */ }Implementations
Sourceimpl<'a> F32Vector<'a>
impl<'a> F32Vector<'a>
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
Sourcepub fn l2_dist_squared(&self, othr: &F32Vector<'a>) -> f32
pub fn l2_dist_squared(&self, othr: &F32Vector<'a>) -> f32
Usage
Computes the SQUARED L2 distance between two vectors. This is cheaper to compute than the regular L2 distance. This is typically useful when comparing two distances :
dist(u,v) < dist(w, x) ⇔ dist(u,v) ** 2 < dist(w,x) ** 2
Panics
Panics in debug mode if the two vectors have different lengths. In release mode, the longest vector will be silently truncated.